# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TaskSummary(object):
    """
    The task summary object type contains the audit summary information and the definition of the task summary object.
    """

    #: A constant which can be used with the model_type property of a TaskSummary.
    #: This constant has a value of "INTEGRATION_TASK"
    MODEL_TYPE_INTEGRATION_TASK = "INTEGRATION_TASK"

    #: A constant which can be used with the model_type property of a TaskSummary.
    #: This constant has a value of "DATA_LOADER_TASK"
    MODEL_TYPE_DATA_LOADER_TASK = "DATA_LOADER_TASK"

    #: A constant which can be used with the model_type property of a TaskSummary.
    #: This constant has a value of "PIPELINE_TASK"
    MODEL_TYPE_PIPELINE_TASK = "PIPELINE_TASK"

    #: A constant which can be used with the model_type property of a TaskSummary.
    #: This constant has a value of "SQL_TASK"
    MODEL_TYPE_SQL_TASK = "SQL_TASK"

    #: A constant which can be used with the model_type property of a TaskSummary.
    #: This constant has a value of "OCI_DATAFLOW_TASK"
    MODEL_TYPE_OCI_DATAFLOW_TASK = "OCI_DATAFLOW_TASK"

    #: A constant which can be used with the model_type property of a TaskSummary.
    #: This constant has a value of "REST_TASK"
    MODEL_TYPE_REST_TASK = "REST_TASK"

    def __init__(self, **kwargs):
        """
        Initializes a new TaskSummary object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.TaskSummaryFromIntegrationTask`
        * :class:`~oci.data_integration.models.TaskSummaryFromSQLTask`
        * :class:`~oci.data_integration.models.TaskSummaryFromOCIDataflowTask`
        * :class:`~oci.data_integration.models.TaskSummaryFromRestTask`
        * :class:`~oci.data_integration.models.TaskSummaryFromPipelineTask`
        * :class:`~oci.data_integration.models.TaskSummaryFromDataLoaderTask`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this TaskSummary.
            Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this TaskSummary.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this TaskSummary.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this TaskSummary.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param name:
            The value to assign to the name property of this TaskSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this TaskSummary.
        :type description: str

        :param object_version:
            The value to assign to the object_version property of this TaskSummary.
        :type object_version: int

        :param object_status:
            The value to assign to the object_status property of this TaskSummary.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this TaskSummary.
        :type identifier: str

        :param input_ports:
            The value to assign to the input_ports property of this TaskSummary.
        :type input_ports: list[oci.data_integration.models.InputPort]

        :param output_ports:
            The value to assign to the output_ports property of this TaskSummary.
        :type output_ports: list[oci.data_integration.models.OutputPort]

        :param parameters:
            The value to assign to the parameters property of this TaskSummary.
        :type parameters: list[oci.data_integration.models.Parameter]

        :param op_config_values:
            The value to assign to the op_config_values property of this TaskSummary.
        :type op_config_values: oci.data_integration.models.ConfigValues

        :param config_provider_delegate:
            The value to assign to the config_provider_delegate property of this TaskSummary.
        :type config_provider_delegate: oci.data_integration.models.ConfigProvider

        :param metadata:
            The value to assign to the metadata property of this TaskSummary.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this TaskSummary.
        :type key_map: dict(str, str)

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'name': 'str',
            'description': 'str',
            'object_version': 'int',
            'object_status': 'int',
            'identifier': 'str',
            'input_ports': 'list[InputPort]',
            'output_ports': 'list[OutputPort]',
            'parameters': 'list[Parameter]',
            'op_config_values': 'ConfigValues',
            'config_provider_delegate': 'ConfigProvider',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'name': 'name',
            'description': 'description',
            'object_version': 'objectVersion',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'input_ports': 'inputPorts',
            'output_ports': 'outputPorts',
            'parameters': 'parameters',
            'op_config_values': 'opConfigValues',
            'config_provider_delegate': 'configProviderDelegate',
            'metadata': 'metadata',
            'key_map': 'keyMap'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._name = None
        self._description = None
        self._object_version = None
        self._object_status = None
        self._identifier = None
        self._input_ports = None
        self._output_ports = None
        self._parameters = None
        self._op_config_values = None
        self._config_provider_delegate = None
        self._metadata = None
        self._key_map = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'INTEGRATION_TASK':
            return 'TaskSummaryFromIntegrationTask'

        if type == 'SQL_TASK':
            return 'TaskSummaryFromSQLTask'

        if type == 'OCI_DATAFLOW_TASK':
            return 'TaskSummaryFromOCIDataflowTask'

        if type == 'REST_TASK':
            return 'TaskSummaryFromRestTask'

        if type == 'PIPELINE_TASK':
            return 'TaskSummaryFromPipelineTask'

        if type == 'DATA_LOADER_TASK':
            return 'TaskSummaryFromDataLoaderTask'
        else:
            return 'TaskSummary'

    @property
    def model_type(self):
        """
        Gets the model_type of this TaskSummary.
        The type of task.

        Allowed values for this property are: "INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this TaskSummary.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this TaskSummary.
        The type of task.


        :param model_type: The model_type of this TaskSummary.
        :type: str
        """
        allowed_values = ["INTEGRATION_TASK", "DATA_LOADER_TASK", "PIPELINE_TASK", "SQL_TASK", "OCI_DATAFLOW_TASK", "REST_TASK"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    @property
    def key(self):
        """
        Gets the key of this TaskSummary.
        Generated key that can be used in API calls to identify task. On scenarios where reference to the task is needed, a value can be passed in create.


        :return: The key of this TaskSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this TaskSummary.
        Generated key that can be used in API calls to identify task. On scenarios where reference to the task is needed, a value can be passed in create.


        :param key: The key of this TaskSummary.
        :type: str
        """
        self._key = key

    @property
    def model_version(self):
        """
        Gets the model_version of this TaskSummary.
        The object's model version.


        :return: The model_version of this TaskSummary.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this TaskSummary.
        The object's model version.


        :param model_version: The model_version of this TaskSummary.
        :type: str
        """
        self._model_version = model_version

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this TaskSummary.

        :return: The parent_ref of this TaskSummary.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this TaskSummary.

        :param parent_ref: The parent_ref of this TaskSummary.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def name(self):
        """
        Gets the name of this TaskSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this TaskSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TaskSummary.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this TaskSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this TaskSummary.
        Detailed description for the object.


        :return: The description of this TaskSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TaskSummary.
        Detailed description for the object.


        :param description: The description of this TaskSummary.
        :type: str
        """
        self._description = description

    @property
    def object_version(self):
        """
        Gets the object_version of this TaskSummary.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this TaskSummary.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this TaskSummary.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this TaskSummary.
        :type: int
        """
        self._object_version = object_version

    @property
    def object_status(self):
        """
        Gets the object_status of this TaskSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this TaskSummary.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this TaskSummary.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this TaskSummary.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this TaskSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this TaskSummary.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this TaskSummary.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this TaskSummary.
        :type: str
        """
        self._identifier = identifier

    @property
    def input_ports(self):
        """
        Gets the input_ports of this TaskSummary.
        An array of input ports.


        :return: The input_ports of this TaskSummary.
        :rtype: list[oci.data_integration.models.InputPort]
        """
        return self._input_ports

    @input_ports.setter
    def input_ports(self, input_ports):
        """
        Sets the input_ports of this TaskSummary.
        An array of input ports.


        :param input_ports: The input_ports of this TaskSummary.
        :type: list[oci.data_integration.models.InputPort]
        """
        self._input_ports = input_ports

    @property
    def output_ports(self):
        """
        Gets the output_ports of this TaskSummary.
        An array of output ports.


        :return: The output_ports of this TaskSummary.
        :rtype: list[oci.data_integration.models.OutputPort]
        """
        return self._output_ports

    @output_ports.setter
    def output_ports(self, output_ports):
        """
        Sets the output_ports of this TaskSummary.
        An array of output ports.


        :param output_ports: The output_ports of this TaskSummary.
        :type: list[oci.data_integration.models.OutputPort]
        """
        self._output_ports = output_ports

    @property
    def parameters(self):
        """
        Gets the parameters of this TaskSummary.
        An array of parameters.


        :return: The parameters of this TaskSummary.
        :rtype: list[oci.data_integration.models.Parameter]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this TaskSummary.
        An array of parameters.


        :param parameters: The parameters of this TaskSummary.
        :type: list[oci.data_integration.models.Parameter]
        """
        self._parameters = parameters

    @property
    def op_config_values(self):
        """
        Gets the op_config_values of this TaskSummary.

        :return: The op_config_values of this TaskSummary.
        :rtype: oci.data_integration.models.ConfigValues
        """
        return self._op_config_values

    @op_config_values.setter
    def op_config_values(self, op_config_values):
        """
        Sets the op_config_values of this TaskSummary.

        :param op_config_values: The op_config_values of this TaskSummary.
        :type: oci.data_integration.models.ConfigValues
        """
        self._op_config_values = op_config_values

    @property
    def config_provider_delegate(self):
        """
        Gets the config_provider_delegate of this TaskSummary.

        :return: The config_provider_delegate of this TaskSummary.
        :rtype: oci.data_integration.models.ConfigProvider
        """
        return self._config_provider_delegate

    @config_provider_delegate.setter
    def config_provider_delegate(self, config_provider_delegate):
        """
        Sets the config_provider_delegate of this TaskSummary.

        :param config_provider_delegate: The config_provider_delegate of this TaskSummary.
        :type: oci.data_integration.models.ConfigProvider
        """
        self._config_provider_delegate = config_provider_delegate

    @property
    def metadata(self):
        """
        Gets the metadata of this TaskSummary.

        :return: The metadata of this TaskSummary.
        :rtype: oci.data_integration.models.ObjectMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this TaskSummary.

        :param metadata: The metadata of this TaskSummary.
        :type: oci.data_integration.models.ObjectMetadata
        """
        self._metadata = metadata

    @property
    def key_map(self):
        """
        Gets the key_map of this TaskSummary.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :return: The key_map of this TaskSummary.
        :rtype: dict(str, str)
        """
        return self._key_map

    @key_map.setter
    def key_map(self, key_map):
        """
        Sets the key_map of this TaskSummary.
        A key map. If provided, key is replaced with generated key. This structure provides mapping between user provided key and generated key.


        :param key_map: The key_map of this TaskSummary.
        :type: dict(str, str)
        """
        self._key_map = key_map

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .typed_object import TypedObject
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ShapeField(TypedObject):
    """
    The shape field object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ShapeField object with values from keyword arguments. The default value of the :py:attr:`~oci.data_connectivity.models.ShapeField.model_type` attribute
        of this class is ``SHAPE_FIELD`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this ShapeField.
            Allowed values for this property are: "SHAPE", "SHAPE_FIELD", "NATIVE_SHAPE_FIELD"
        :type model_type: str

        :param key:
            The value to assign to the key property of this ShapeField.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this ShapeField.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this ShapeField.
        :type parent_ref: oci.data_connectivity.models.ParentReference

        :param config_values:
            The value to assign to the config_values property of this ShapeField.
        :type config_values: oci.data_connectivity.models.ConfigValues

        :param object_status:
            The value to assign to the object_status property of this ShapeField.
        :type object_status: int

        :param name:
            The value to assign to the name property of this ShapeField.
        :type name: str

        :param description:
            The value to assign to the description property of this ShapeField.
        :type description: str

        :param type:
            The value to assign to the type property of this ShapeField.
        :type type: object

        :param labels:
            The value to assign to the labels property of this ShapeField.
        :type labels: list[str]

        :param native_shape_field:
            The value to assign to the native_shape_field property of this ShapeField.
        :type native_shape_field: oci.data_connectivity.models.NativeShapeField

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'config_values': 'ConfigValues',
            'object_status': 'int',
            'name': 'str',
            'description': 'str',
            'type': 'object',
            'labels': 'list[str]',
            'native_shape_field': 'NativeShapeField'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'config_values': 'configValues',
            'object_status': 'objectStatus',
            'name': 'name',
            'description': 'description',
            'type': 'type',
            'labels': 'labels',
            'native_shape_field': 'nativeShapeField'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._config_values = None
        self._object_status = None
        self._name = None
        self._description = None
        self._type = None
        self._labels = None
        self._native_shape_field = None
        self._model_type = 'SHAPE_FIELD'

    @property
    def type(self):
        """
        Gets the type of this ShapeField.
        The type reference.


        :return: The type of this ShapeField.
        :rtype: object
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ShapeField.
        The type reference.


        :param type: The type of this ShapeField.
        :type: object
        """
        self._type = type

    @property
    def labels(self):
        """
        Gets the labels of this ShapeField.
        Labels are keywords or labels that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :return: The labels of this ShapeField.
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this ShapeField.
        Labels are keywords or labels that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :param labels: The labels of this ShapeField.
        :type: list[str]
        """
        self._labels = labels

    @property
    def native_shape_field(self):
        """
        Gets the native_shape_field of this ShapeField.

        :return: The native_shape_field of this ShapeField.
        :rtype: oci.data_connectivity.models.NativeShapeField
        """
        return self._native_shape_field

    @native_shape_field.setter
    def native_shape_field(self, native_shape_field):
        """
        Sets the native_shape_field of this ShapeField.

        :param native_shape_field: The native_shape_field of this ShapeField.
        :type: oci.data_connectivity.models.NativeShapeField
        """
        self._native_shape_field = native_shape_field

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAuthenticationProviderDetails(object):
    """
    Properties required to create a new Authentication Provider.
    """

    #: A constant which can be used with the grant_type property of a CreateAuthenticationProviderDetails.
    #: This constant has a value of "CLIENT_CREDENTIALS"
    GRANT_TYPE_CLIENT_CREDENTIALS = "CLIENT_CREDENTIALS"

    #: A constant which can be used with the grant_type property of a CreateAuthenticationProviderDetails.
    #: This constant has a value of "AUTHORIZATION_CODE"
    GRANT_TYPE_AUTHORIZATION_CODE = "AUTHORIZATION_CODE"

    #: A constant which can be used with the identity_provider property of a CreateAuthenticationProviderDetails.
    #: This constant has a value of "GENERIC"
    IDENTITY_PROVIDER_GENERIC = "GENERIC"

    #: A constant which can be used with the identity_provider property of a CreateAuthenticationProviderDetails.
    #: This constant has a value of "OAM"
    IDENTITY_PROVIDER_OAM = "OAM"

    #: A constant which can be used with the identity_provider property of a CreateAuthenticationProviderDetails.
    #: This constant has a value of "GOOGLE"
    IDENTITY_PROVIDER_GOOGLE = "GOOGLE"

    #: A constant which can be used with the identity_provider property of a CreateAuthenticationProviderDetails.
    #: This constant has a value of "MICROSOFT"
    IDENTITY_PROVIDER_MICROSOFT = "MICROSOFT"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAuthenticationProviderDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param grant_type:
            The value to assign to the grant_type property of this CreateAuthenticationProviderDetails.
            Allowed values for this property are: "CLIENT_CREDENTIALS", "AUTHORIZATION_CODE"
        :type grant_type: str

        :param identity_provider:
            The value to assign to the identity_provider property of this CreateAuthenticationProviderDetails.
            Allowed values for this property are: "GENERIC", "OAM", "GOOGLE", "MICROSOFT"
        :type identity_provider: str

        :param name:
            The value to assign to the name property of this CreateAuthenticationProviderDetails.
        :type name: str

        :param token_endpoint_url:
            The value to assign to the token_endpoint_url property of this CreateAuthenticationProviderDetails.
        :type token_endpoint_url: str

        :param authorization_endpoint_url:
            The value to assign to the authorization_endpoint_url property of this CreateAuthenticationProviderDetails.
        :type authorization_endpoint_url: str

        :param short_authorization_code_request_url:
            The value to assign to the short_authorization_code_request_url property of this CreateAuthenticationProviderDetails.
        :type short_authorization_code_request_url: str

        :param revoke_token_endpoint_url:
            The value to assign to the revoke_token_endpoint_url property of this CreateAuthenticationProviderDetails.
        :type revoke_token_endpoint_url: str

        :param client_id:
            The value to assign to the client_id property of this CreateAuthenticationProviderDetails.
        :type client_id: str

        :param client_secret:
            The value to assign to the client_secret property of this CreateAuthenticationProviderDetails.
        :type client_secret: str

        :param scopes:
            The value to assign to the scopes property of this CreateAuthenticationProviderDetails.
        :type scopes: str

        :param subject_claim:
            The value to assign to the subject_claim property of this CreateAuthenticationProviderDetails.
        :type subject_claim: str

        :param refresh_token_retention_period_in_days:
            The value to assign to the refresh_token_retention_period_in_days property of this CreateAuthenticationProviderDetails.
        :type refresh_token_retention_period_in_days: int

        :param redirect_url:
            The value to assign to the redirect_url property of this CreateAuthenticationProviderDetails.
        :type redirect_url: str

        :param is_visible:
            The value to assign to the is_visible property of this CreateAuthenticationProviderDetails.
        :type is_visible: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateAuthenticationProviderDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateAuthenticationProviderDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'grant_type': 'str',
            'identity_provider': 'str',
            'name': 'str',
            'token_endpoint_url': 'str',
            'authorization_endpoint_url': 'str',
            'short_authorization_code_request_url': 'str',
            'revoke_token_endpoint_url': 'str',
            'client_id': 'str',
            'client_secret': 'str',
            'scopes': 'str',
            'subject_claim': 'str',
            'refresh_token_retention_period_in_days': 'int',
            'redirect_url': 'str',
            'is_visible': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'grant_type': 'grantType',
            'identity_provider': 'identityProvider',
            'name': 'name',
            'token_endpoint_url': 'tokenEndpointUrl',
            'authorization_endpoint_url': 'authorizationEndpointUrl',
            'short_authorization_code_request_url': 'shortAuthorizationCodeRequestUrl',
            'revoke_token_endpoint_url': 'revokeTokenEndpointUrl',
            'client_id': 'clientId',
            'client_secret': 'clientSecret',
            'scopes': 'scopes',
            'subject_claim': 'subjectClaim',
            'refresh_token_retention_period_in_days': 'refreshTokenRetentionPeriodInDays',
            'redirect_url': 'redirectUrl',
            'is_visible': 'isVisible',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._grant_type = None
        self._identity_provider = None
        self._name = None
        self._token_endpoint_url = None
        self._authorization_endpoint_url = None
        self._short_authorization_code_request_url = None
        self._revoke_token_endpoint_url = None
        self._client_id = None
        self._client_secret = None
        self._scopes = None
        self._subject_claim = None
        self._refresh_token_retention_period_in_days = None
        self._redirect_url = None
        self._is_visible = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def grant_type(self):
        """
        **[Required]** Gets the grant_type of this CreateAuthenticationProviderDetails.
        The grant type for the Authentication Provider.

        Allowed values for this property are: "CLIENT_CREDENTIALS", "AUTHORIZATION_CODE"


        :return: The grant_type of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._grant_type

    @grant_type.setter
    def grant_type(self, grant_type):
        """
        Sets the grant_type of this CreateAuthenticationProviderDetails.
        The grant type for the Authentication Provider.


        :param grant_type: The grant_type of this CreateAuthenticationProviderDetails.
        :type: str
        """
        allowed_values = ["CLIENT_CREDENTIALS", "AUTHORIZATION_CODE"]
        if not value_allowed_none_or_none_sentinel(grant_type, allowed_values):
            raise ValueError(
                "Invalid value for `grant_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._grant_type = grant_type

    @property
    def identity_provider(self):
        """
        **[Required]** Gets the identity_provider of this CreateAuthenticationProviderDetails.
        Which type of Identity Provider (IDP) you are using.

        Allowed values for this property are: "GENERIC", "OAM", "GOOGLE", "MICROSOFT"


        :return: The identity_provider of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._identity_provider

    @identity_provider.setter
    def identity_provider(self, identity_provider):
        """
        Sets the identity_provider of this CreateAuthenticationProviderDetails.
        Which type of Identity Provider (IDP) you are using.


        :param identity_provider: The identity_provider of this CreateAuthenticationProviderDetails.
        :type: str
        """
        allowed_values = ["GENERIC", "OAM", "GOOGLE", "MICROSOFT"]
        if not value_allowed_none_or_none_sentinel(identity_provider, allowed_values):
            raise ValueError(
                "Invalid value for `identity_provider`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._identity_provider = identity_provider

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateAuthenticationProviderDetails.
        A name to identify the Authentication Provider.


        :return: The name of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateAuthenticationProviderDetails.
        A name to identify the Authentication Provider.


        :param name: The name of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._name = name

    @property
    def token_endpoint_url(self):
        """
        **[Required]** Gets the token_endpoint_url of this CreateAuthenticationProviderDetails.
        The IDPs URL for requesting access tokens.


        :return: The token_endpoint_url of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._token_endpoint_url

    @token_endpoint_url.setter
    def token_endpoint_url(self, token_endpoint_url):
        """
        Sets the token_endpoint_url of this CreateAuthenticationProviderDetails.
        The IDPs URL for requesting access tokens.


        :param token_endpoint_url: The token_endpoint_url of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._token_endpoint_url = token_endpoint_url

    @property
    def authorization_endpoint_url(self):
        """
        **[Required]** Gets the authorization_endpoint_url of this CreateAuthenticationProviderDetails.
        The IDPs URL for the page that users authenticate with by entering the user name and password.


        :return: The authorization_endpoint_url of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._authorization_endpoint_url

    @authorization_endpoint_url.setter
    def authorization_endpoint_url(self, authorization_endpoint_url):
        """
        Sets the authorization_endpoint_url of this CreateAuthenticationProviderDetails.
        The IDPs URL for the page that users authenticate with by entering the user name and password.


        :param authorization_endpoint_url: The authorization_endpoint_url of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._authorization_endpoint_url = authorization_endpoint_url

    @property
    def short_authorization_code_request_url(self):
        """
        Gets the short_authorization_code_request_url of this CreateAuthenticationProviderDetails.
        A shortened version of the authorization URL, which you can get from a URL shortener service (one that allows
        you to send query parameters).  You might need this because the generated authorization-code-request URL
        could be too long for SMS and older smart phones.


        :return: The short_authorization_code_request_url of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._short_authorization_code_request_url

    @short_authorization_code_request_url.setter
    def short_authorization_code_request_url(self, short_authorization_code_request_url):
        """
        Sets the short_authorization_code_request_url of this CreateAuthenticationProviderDetails.
        A shortened version of the authorization URL, which you can get from a URL shortener service (one that allows
        you to send query parameters).  You might need this because the generated authorization-code-request URL
        could be too long for SMS and older smart phones.


        :param short_authorization_code_request_url: The short_authorization_code_request_url of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._short_authorization_code_request_url = short_authorization_code_request_url

    @property
    def revoke_token_endpoint_url(self):
        """
        Gets the revoke_token_endpoint_url of this CreateAuthenticationProviderDetails.
        If you want to revoke all the refresh tokens and access tokens of the logged-in user from a dialog flow, then
        you need the IDP's revoke refresh token URL. If you provide this URL, then you can use the System.OAuth2ResetTokens
        component to revoke the user's tokens for this service.


        :return: The revoke_token_endpoint_url of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._revoke_token_endpoint_url

    @revoke_token_endpoint_url.setter
    def revoke_token_endpoint_url(self, revoke_token_endpoint_url):
        """
        Sets the revoke_token_endpoint_url of this CreateAuthenticationProviderDetails.
        If you want to revoke all the refresh tokens and access tokens of the logged-in user from a dialog flow, then
        you need the IDP's revoke refresh token URL. If you provide this URL, then you can use the System.OAuth2ResetTokens
        component to revoke the user's tokens for this service.


        :param revoke_token_endpoint_url: The revoke_token_endpoint_url of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._revoke_token_endpoint_url = revoke_token_endpoint_url

    @property
    def client_id(self):
        """
        **[Required]** Gets the client_id of this CreateAuthenticationProviderDetails.
        The client ID for the IDP application (OAuth Client) that was registered as described in Identity Provider Registration.
        With Microsoft identity platform, use the application ID.


        :return: The client_id of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """
        Sets the client_id of this CreateAuthenticationProviderDetails.
        The client ID for the IDP application (OAuth Client) that was registered as described in Identity Provider Registration.
        With Microsoft identity platform, use the application ID.


        :param client_id: The client_id of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._client_id = client_id

    @property
    def client_secret(self):
        """
        **[Required]** Gets the client_secret of this CreateAuthenticationProviderDetails.
        The client secret for the IDP application (OAuth Client) that was registered as described in Identity Provider
        Registration. With Microsoft identity platform, use the application secret.


        :return: The client_secret of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._client_secret

    @client_secret.setter
    def client_secret(self, client_secret):
        """
        Sets the client_secret of this CreateAuthenticationProviderDetails.
        The client secret for the IDP application (OAuth Client) that was registered as described in Identity Provider
        Registration. With Microsoft identity platform, use the application secret.


        :param client_secret: The client_secret of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._client_secret = client_secret

    @property
    def scopes(self):
        """
        **[Required]** Gets the scopes of this CreateAuthenticationProviderDetails.
        A space-separated list of the scopes that must be included when Digital Assistant requests an access token from
        the provider. Include all the scopes that are required to access the resources. If refresh tokens are enabled,
        include the scope that\u2019s necessary to get the refresh token (typically offline_access).


        :return: The scopes of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """
        Sets the scopes of this CreateAuthenticationProviderDetails.
        A space-separated list of the scopes that must be included when Digital Assistant requests an access token from
        the provider. Include all the scopes that are required to access the resources. If refresh tokens are enabled,
        include the scope that\u2019s necessary to get the refresh token (typically offline_access).


        :param scopes: The scopes of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._scopes = scopes

    @property
    def subject_claim(self):
        """
        **[Required]** Gets the subject_claim of this CreateAuthenticationProviderDetails.
        The access-token profile claim to use to identify the user.


        :return: The subject_claim of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._subject_claim

    @subject_claim.setter
    def subject_claim(self, subject_claim):
        """
        Sets the subject_claim of this CreateAuthenticationProviderDetails.
        The access-token profile claim to use to identify the user.


        :param subject_claim: The subject_claim of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._subject_claim = subject_claim

    @property
    def refresh_token_retention_period_in_days(self):
        """
        Gets the refresh_token_retention_period_in_days of this CreateAuthenticationProviderDetails.
        The number of days to keep the refresh token in the Digital Assistant cache.


        :return: The refresh_token_retention_period_in_days of this CreateAuthenticationProviderDetails.
        :rtype: int
        """
        return self._refresh_token_retention_period_in_days

    @refresh_token_retention_period_in_days.setter
    def refresh_token_retention_period_in_days(self, refresh_token_retention_period_in_days):
        """
        Sets the refresh_token_retention_period_in_days of this CreateAuthenticationProviderDetails.
        The number of days to keep the refresh token in the Digital Assistant cache.


        :param refresh_token_retention_period_in_days: The refresh_token_retention_period_in_days of this CreateAuthenticationProviderDetails.
        :type: int
        """
        self._refresh_token_retention_period_in_days = refresh_token_retention_period_in_days

    @property
    def redirect_url(self):
        """
        Gets the redirect_url of this CreateAuthenticationProviderDetails.
        The OAuth Redirect URL.


        :return: The redirect_url of this CreateAuthenticationProviderDetails.
        :rtype: str
        """
        return self._redirect_url

    @redirect_url.setter
    def redirect_url(self, redirect_url):
        """
        Sets the redirect_url of this CreateAuthenticationProviderDetails.
        The OAuth Redirect URL.


        :param redirect_url: The redirect_url of this CreateAuthenticationProviderDetails.
        :type: str
        """
        self._redirect_url = redirect_url

    @property
    def is_visible(self):
        """
        Gets the is_visible of this CreateAuthenticationProviderDetails.
        Whether this Authentication Provider is visible in the ODA UI.


        :return: The is_visible of this CreateAuthenticationProviderDetails.
        :rtype: bool
        """
        return self._is_visible

    @is_visible.setter
    def is_visible(self, is_visible):
        """
        Sets the is_visible of this CreateAuthenticationProviderDetails.
        Whether this Authentication Provider is visible in the ODA UI.


        :param is_visible: The is_visible of this CreateAuthenticationProviderDetails.
        :type: bool
        """
        self._is_visible = is_visible

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateAuthenticationProviderDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateAuthenticationProviderDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateAuthenticationProviderDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateAuthenticationProviderDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateAuthenticationProviderDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateAuthenticationProviderDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateAuthenticationProviderDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateAuthenticationProviderDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AbstractWriteAttribute(object):
    """
    The abstract write attribute.
    """

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "ORACLEWRITEATTRIBUTE"
    MODEL_TYPE_ORACLEWRITEATTRIBUTE = "ORACLEWRITEATTRIBUTE"

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "ORACLEATPWRITEATTRIBUTE"
    MODEL_TYPE_ORACLEATPWRITEATTRIBUTE = "ORACLEATPWRITEATTRIBUTE"

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "ORACLEADWCWRITEATTRIBUTE"
    MODEL_TYPE_ORACLEADWCWRITEATTRIBUTE = "ORACLEADWCWRITEATTRIBUTE"

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "OBJECTSTORAGEWRITEATTRIBUTE"
    MODEL_TYPE_OBJECTSTORAGEWRITEATTRIBUTE = "OBJECTSTORAGEWRITEATTRIBUTE"

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "ORACLE_WRITE_ATTRIBUTE"
    MODEL_TYPE_ORACLE_WRITE_ATTRIBUTE = "ORACLE_WRITE_ATTRIBUTE"

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "ORACLE_ATP_WRITE_ATTRIBUTE"
    MODEL_TYPE_ORACLE_ATP_WRITE_ATTRIBUTE = "ORACLE_ATP_WRITE_ATTRIBUTE"

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "ORACLE_ADWC_WRITE_ATTRIBUTE"
    MODEL_TYPE_ORACLE_ADWC_WRITE_ATTRIBUTE = "ORACLE_ADWC_WRITE_ATTRIBUTE"

    #: A constant which can be used with the model_type property of a AbstractWriteAttribute.
    #: This constant has a value of "OBJECT_STORAGE_WRITE_ATTRIBUTE"
    MODEL_TYPE_OBJECT_STORAGE_WRITE_ATTRIBUTE = "OBJECT_STORAGE_WRITE_ATTRIBUTE"

    def __init__(self, **kwargs):
        """
        Initializes a new AbstractWriteAttribute object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.OracleAdwcWriteAttribute`
        * :class:`~oci.data_integration.models.OracleAtpWriteAttributes`
        * :class:`~oci.data_integration.models.OracleWriteAttribute`
        * :class:`~oci.data_integration.models.OracleWriteAttributes`
        * :class:`~oci.data_integration.models.OracleAtpWriteAttribute`
        * :class:`~oci.data_integration.models.ObjectStorageWriteAttribute`
        * :class:`~oci.data_integration.models.OracleAdwcWriteAttributes`
        * :class:`~oci.data_integration.models.ObjectStorageWriteAttributes`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this AbstractWriteAttribute.
            Allowed values for this property are: "ORACLEWRITEATTRIBUTE", "ORACLEATPWRITEATTRIBUTE", "ORACLEADWCWRITEATTRIBUTE", "OBJECTSTORAGEWRITEATTRIBUTE", "ORACLE_WRITE_ATTRIBUTE", "ORACLE_ATP_WRITE_ATTRIBUTE", "ORACLE_ADWC_WRITE_ATTRIBUTE", "OBJECT_STORAGE_WRITE_ATTRIBUTE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        """
        self.swagger_types = {
            'model_type': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType'
        }

        self._model_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'ORACLEADWCWRITEATTRIBUTE':
            return 'OracleAdwcWriteAttribute'

        if type == 'ORACLE_ATP_WRITE_ATTRIBUTE':
            return 'OracleAtpWriteAttributes'

        if type == 'ORACLEWRITEATTRIBUTE':
            return 'OracleWriteAttribute'

        if type == 'ORACLE_WRITE_ATTRIBUTE':
            return 'OracleWriteAttributes'

        if type == 'ORACLEATPWRITEATTRIBUTE':
            return 'OracleAtpWriteAttribute'

        if type == 'OBJECTSTORAGEWRITEATTRIBUTE':
            return 'ObjectStorageWriteAttribute'

        if type == 'ORACLE_ADWC_WRITE_ATTRIBUTE':
            return 'OracleAdwcWriteAttributes'

        if type == 'OBJECT_STORAGE_WRITE_ATTRIBUTE':
            return 'ObjectStorageWriteAttributes'
        else:
            return 'AbstractWriteAttribute'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this AbstractWriteAttribute.
        The type of the abstract write attribute.

        Allowed values for this property are: "ORACLEWRITEATTRIBUTE", "ORACLEATPWRITEATTRIBUTE", "ORACLEADWCWRITEATTRIBUTE", "OBJECTSTORAGEWRITEATTRIBUTE", "ORACLE_WRITE_ATTRIBUTE", "ORACLE_ATP_WRITE_ATTRIBUTE", "ORACLE_ADWC_WRITE_ATTRIBUTE", "OBJECT_STORAGE_WRITE_ATTRIBUTE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this AbstractWriteAttribute.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this AbstractWriteAttribute.
        The type of the abstract write attribute.


        :param model_type: The model_type of this AbstractWriteAttribute.
        :type: str
        """
        allowed_values = ["ORACLEWRITEATTRIBUTE", "ORACLEATPWRITEATTRIBUTE", "ORACLEADWCWRITEATTRIBUTE", "OBJECTSTORAGEWRITEATTRIBUTE", "ORACLE_WRITE_ATTRIBUTE", "ORACLE_ATP_WRITE_ATTRIBUTE", "ORACLE_ADWC_WRITE_ATTRIBUTE", "OBJECT_STORAGE_WRITE_ATTRIBUTE"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DbServerPatchingDetails(object):
    """
    The scheduling details for the quarterly maintenance window. Patching and system updates take place during the maintenance window.
    """

    #: A constant which can be used with the patching_status property of a DbServerPatchingDetails.
    #: This constant has a value of "SCHEDULED"
    PATCHING_STATUS_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the patching_status property of a DbServerPatchingDetails.
    #: This constant has a value of "MAINTENANCE_IN_PROGRESS"
    PATCHING_STATUS_MAINTENANCE_IN_PROGRESS = "MAINTENANCE_IN_PROGRESS"

    #: A constant which can be used with the patching_status property of a DbServerPatchingDetails.
    #: This constant has a value of "FAILED"
    PATCHING_STATUS_FAILED = "FAILED"

    #: A constant which can be used with the patching_status property of a DbServerPatchingDetails.
    #: This constant has a value of "COMPLETE"
    PATCHING_STATUS_COMPLETE = "COMPLETE"

    def __init__(self, **kwargs):
        """
        Initializes a new DbServerPatchingDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param estimated_patch_duration:
            The value to assign to the estimated_patch_duration property of this DbServerPatchingDetails.
        :type estimated_patch_duration: int

        :param patching_status:
            The value to assign to the patching_status property of this DbServerPatchingDetails.
            Allowed values for this property are: "SCHEDULED", "MAINTENANCE_IN_PROGRESS", "FAILED", "COMPLETE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type patching_status: str

        :param time_patching_started:
            The value to assign to the time_patching_started property of this DbServerPatchingDetails.
        :type time_patching_started: datetime

        :param time_patching_ended:
            The value to assign to the time_patching_ended property of this DbServerPatchingDetails.
        :type time_patching_ended: datetime

        """
        self.swagger_types = {
            'estimated_patch_duration': 'int',
            'patching_status': 'str',
            'time_patching_started': 'datetime',
            'time_patching_ended': 'datetime'
        }

        self.attribute_map = {
            'estimated_patch_duration': 'estimatedPatchDuration',
            'patching_status': 'patchingStatus',
            'time_patching_started': 'timePatchingStarted',
            'time_patching_ended': 'timePatchingEnded'
        }

        self._estimated_patch_duration = None
        self._patching_status = None
        self._time_patching_started = None
        self._time_patching_ended = None

    @property
    def estimated_patch_duration(self):
        """
        Gets the estimated_patch_duration of this DbServerPatchingDetails.
        Estimated time, in minutes, to patch one database server.


        :return: The estimated_patch_duration of this DbServerPatchingDetails.
        :rtype: int
        """
        return self._estimated_patch_duration

    @estimated_patch_duration.setter
    def estimated_patch_duration(self, estimated_patch_duration):
        """
        Sets the estimated_patch_duration of this DbServerPatchingDetails.
        Estimated time, in minutes, to patch one database server.


        :param estimated_patch_duration: The estimated_patch_duration of this DbServerPatchingDetails.
        :type: int
        """
        self._estimated_patch_duration = estimated_patch_duration

    @property
    def patching_status(self):
        """
        Gets the patching_status of this DbServerPatchingDetails.
        The status of the patching operation.

        Allowed values for this property are: "SCHEDULED", "MAINTENANCE_IN_PROGRESS", "FAILED", "COMPLETE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The patching_status of this DbServerPatchingDetails.
        :rtype: str
        """
        return self._patching_status

    @patching_status.setter
    def patching_status(self, patching_status):
        """
        Sets the patching_status of this DbServerPatchingDetails.
        The status of the patching operation.


        :param patching_status: The patching_status of this DbServerPatchingDetails.
        :type: str
        """
        allowed_values = ["SCHEDULED", "MAINTENANCE_IN_PROGRESS", "FAILED", "COMPLETE"]
        if not value_allowed_none_or_none_sentinel(patching_status, allowed_values):
            patching_status = 'UNKNOWN_ENUM_VALUE'
        self._patching_status = patching_status

    @property
    def time_patching_started(self):
        """
        Gets the time_patching_started of this DbServerPatchingDetails.
        The time when the patching operation started.


        :return: The time_patching_started of this DbServerPatchingDetails.
        :rtype: datetime
        """
        return self._time_patching_started

    @time_patching_started.setter
    def time_patching_started(self, time_patching_started):
        """
        Sets the time_patching_started of this DbServerPatchingDetails.
        The time when the patching operation started.


        :param time_patching_started: The time_patching_started of this DbServerPatchingDetails.
        :type: datetime
        """
        self._time_patching_started = time_patching_started

    @property
    def time_patching_ended(self):
        """
        Gets the time_patching_ended of this DbServerPatchingDetails.
        The time when the patching operation ended.


        :return: The time_patching_ended of this DbServerPatchingDetails.
        :rtype: datetime
        """
        return self._time_patching_ended

    @time_patching_ended.setter
    def time_patching_ended(self, time_patching_ended):
        """
        Sets the time_patching_ended of this DbServerPatchingDetails.
        The time when the patching operation ended.


        :param time_patching_ended: The time_patching_ended of this DbServerPatchingDetails.
        :type: datetime
        """
        self._time_patching_ended = time_patching_ended

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class DataLabelingManagementClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.data_labeling_service.DataLabelingManagementClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new DataLabelingManagementClientCompositeOperations object

        :param DataLabelingManagementClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def add_dataset_labels_and_wait_for_state(self, dataset_id, add_dataset_labels_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.add_dataset_labels` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param oci.data_labeling_service.models.AddDatasetLabelsDetails add_dataset_labels_details: (required)
            Details for adding Labels to the LabelSet of the Dataset.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.add_dataset_labels`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.add_dataset_labels(dataset_id, add_dataset_labels_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def change_dataset_compartment_and_wait_for_state(self, dataset_id, change_dataset_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.change_dataset_compartment` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param oci.data_labeling_service.models.ChangeDatasetCompartmentDetails change_dataset_compartment_details: (required)
            Details for changing the compartment of a Dataset

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.change_dataset_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_dataset_compartment(dataset_id, change_dataset_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_dataset_and_wait_for_state(self, create_dataset_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.create_dataset` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_labeling_service.models.CreateDatasetDetails create_dataset_details: (required)
            Details for the new Dataset.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.create_dataset`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_dataset(create_dataset_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_dataset_and_wait_for_state(self, dataset_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.delete_dataset` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.delete_dataset`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_dataset(dataset_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def generate_dataset_records_and_wait_for_state(self, dataset_id, generate_dataset_records_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.generate_dataset_records` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param oci.data_labeling_service.models.GenerateDatasetRecordsDetails generate_dataset_records_details: (required)
            Details for generating Dataset records.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.generate_dataset_records`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.generate_dataset_records(dataset_id, generate_dataset_records_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def remove_dataset_labels_and_wait_for_state(self, dataset_id, remove_dataset_labels_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.remove_dataset_labels` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param oci.data_labeling_service.models.RemoveDatasetLabelsDetails remove_dataset_labels_details: (required)
            Details for removing Labels from the LabelSet of the Dataset.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.remove_dataset_labels`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.remove_dataset_labels(dataset_id, remove_dataset_labels_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def rename_dataset_labels_and_wait_for_state(self, dataset_id, rename_dataset_labels_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.rename_dataset_labels` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param oci.data_labeling_service.models.RenameDatasetLabelsDetails rename_dataset_labels_details: (required)
            Details for renaming Labels in the LabelSet of the Dataset.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.rename_dataset_labels`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.rename_dataset_labels(dataset_id, rename_dataset_labels_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def snapshot_dataset_and_wait_for_state(self, dataset_id, snapshot_dataset_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.snapshot_dataset` and waits for the :py:class:`~oci.data_labeling_service.models.WorkRequest`
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param oci.data_labeling_service.models.SnapshotDatasetDetails snapshot_dataset_details: (required)
            Details of creating a snapshot of the Dataset's Records and Annotations

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.snapshot_dataset`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.snapshot_dataset(dataset_id, snapshot_dataset_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_dataset_and_wait_for_state(self, dataset_id, update_dataset_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.update_dataset` and waits for the :py:class:`~oci.data_labeling_service.models.Dataset` acted upon
        to enter the given state(s).

        :param str dataset_id: (required)
            Unique Dataset OCID

        :param oci.data_labeling_service.models.UpdateDatasetDetails update_dataset_details: (required)
            Details for updating a Dataset.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_labeling_service.models.Dataset.lifecycle_state`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_labeling_service.DataLabelingManagementClient.update_dataset`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_dataset(dataset_id, update_dataset_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.data.id

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_dataset(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'lifecycle_state') and getattr(r.data, 'lifecycle_state').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateProductLicenseDetails(object):
    """
    Details for creating a new product license.
    """

    #: A constant which can be used with the license_unit property of a CreateProductLicenseDetails.
    #: This constant has a value of "OCPU"
    LICENSE_UNIT_OCPU = "OCPU"

    #: A constant which can be used with the license_unit property of a CreateProductLicenseDetails.
    #: This constant has a value of "NAMED_USER_PLUS"
    LICENSE_UNIT_NAMED_USER_PLUS = "NAMED_USER_PLUS"

    #: A constant which can be used with the license_unit property of a CreateProductLicenseDetails.
    #: This constant has a value of "PROCESSORS"
    LICENSE_UNIT_PROCESSORS = "PROCESSORS"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateProductLicenseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateProductLicenseDetails.
        :type compartment_id: str

        :param is_vendor_oracle:
            The value to assign to the is_vendor_oracle property of this CreateProductLicenseDetails.
        :type is_vendor_oracle: bool

        :param display_name:
            The value to assign to the display_name property of this CreateProductLicenseDetails.
        :type display_name: str

        :param license_unit:
            The value to assign to the license_unit property of this CreateProductLicenseDetails.
            Allowed values for this property are: "OCPU", "NAMED_USER_PLUS", "PROCESSORS"
        :type license_unit: str

        :param vendor_name:
            The value to assign to the vendor_name property of this CreateProductLicenseDetails.
        :type vendor_name: str

        :param images:
            The value to assign to the images property of this CreateProductLicenseDetails.
        :type images: list[oci.license_manager.models.ImageDetails]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateProductLicenseDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateProductLicenseDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'is_vendor_oracle': 'bool',
            'display_name': 'str',
            'license_unit': 'str',
            'vendor_name': 'str',
            'images': 'list[ImageDetails]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'is_vendor_oracle': 'isVendorOracle',
            'display_name': 'displayName',
            'license_unit': 'licenseUnit',
            'vendor_name': 'vendorName',
            'images': 'images',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._is_vendor_oracle = None
        self._display_name = None
        self._license_unit = None
        self._vendor_name = None
        self._images = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateProductLicenseDetails.
        The compartment `OCID`__ where product licenses are created.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateProductLicenseDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateProductLicenseDetails.
        The compartment `OCID`__ where product licenses are created.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateProductLicenseDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_vendor_oracle(self):
        """
        **[Required]** Gets the is_vendor_oracle of this CreateProductLicenseDetails.
        Specifies if the product license vendor is Oracle or a third party.


        :return: The is_vendor_oracle of this CreateProductLicenseDetails.
        :rtype: bool
        """
        return self._is_vendor_oracle

    @is_vendor_oracle.setter
    def is_vendor_oracle(self, is_vendor_oracle):
        """
        Sets the is_vendor_oracle of this CreateProductLicenseDetails.
        Specifies if the product license vendor is Oracle or a third party.


        :param is_vendor_oracle: The is_vendor_oracle of this CreateProductLicenseDetails.
        :type: bool
        """
        self._is_vendor_oracle = is_vendor_oracle

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateProductLicenseDetails.
        Name of the product license.


        :return: The display_name of this CreateProductLicenseDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateProductLicenseDetails.
        Name of the product license.


        :param display_name: The display_name of this CreateProductLicenseDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def license_unit(self):
        """
        **[Required]** Gets the license_unit of this CreateProductLicenseDetails.
        The product license unit.

        Allowed values for this property are: "OCPU", "NAMED_USER_PLUS", "PROCESSORS"


        :return: The license_unit of this CreateProductLicenseDetails.
        :rtype: str
        """
        return self._license_unit

    @license_unit.setter
    def license_unit(self, license_unit):
        """
        Sets the license_unit of this CreateProductLicenseDetails.
        The product license unit.


        :param license_unit: The license_unit of this CreateProductLicenseDetails.
        :type: str
        """
        allowed_values = ["OCPU", "NAMED_USER_PLUS", "PROCESSORS"]
        if not value_allowed_none_or_none_sentinel(license_unit, allowed_values):
            raise ValueError(
                "Invalid value for `license_unit`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._license_unit = license_unit

    @property
    def vendor_name(self):
        """
        Gets the vendor_name of this CreateProductLicenseDetails.
        The product license vendor name, for example: Microsoft, RHEL, and so on.


        :return: The vendor_name of this CreateProductLicenseDetails.
        :rtype: str
        """
        return self._vendor_name

    @vendor_name.setter
    def vendor_name(self, vendor_name):
        """
        Sets the vendor_name of this CreateProductLicenseDetails.
        The product license vendor name, for example: Microsoft, RHEL, and so on.


        :param vendor_name: The vendor_name of this CreateProductLicenseDetails.
        :type: str
        """
        self._vendor_name = vendor_name

    @property
    def images(self):
        """
        Gets the images of this CreateProductLicenseDetails.
        The image details associated with the product license.


        :return: The images of this CreateProductLicenseDetails.
        :rtype: list[oci.license_manager.models.ImageDetails]
        """
        return self._images

    @images.setter
    def images(self, images):
        """
        Sets the images of this CreateProductLicenseDetails.
        The image details associated with the product license.


        :param images: The images of this CreateProductLicenseDetails.
        :type: list[oci.license_manager.models.ImageDetails]
        """
        self._images = images

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateProductLicenseDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateProductLicenseDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateProductLicenseDetails.
        Simple key-value pair that is applied without any predefined name, type, or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateProductLicenseDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateProductLicenseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateProductLicenseDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateProductLicenseDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateProductLicenseDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchMonitoredResourceMembersDetails(object):
    """
    The search criteria for listing monitored resource member targets.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SearchMonitoredResourceMembersDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param destination_resource_id:
            The value to assign to the destination_resource_id property of this SearchMonitoredResourceMembersDetails.
        :type destination_resource_id: str

        :param limit_level:
            The value to assign to the limit_level property of this SearchMonitoredResourceMembersDetails.
        :type limit_level: int

        """
        self.swagger_types = {
            'destination_resource_id': 'str',
            'limit_level': 'int'
        }

        self.attribute_map = {
            'destination_resource_id': 'destinationResourceId',
            'limit_level': 'limitLevel'
        }

        self._destination_resource_id = None
        self._limit_level = None

    @property
    def destination_resource_id(self):
        """
        Gets the destination_resource_id of this SearchMonitoredResourceMembersDetails.
        Destination Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The destination_resource_id of this SearchMonitoredResourceMembersDetails.
        :rtype: str
        """
        return self._destination_resource_id

    @destination_resource_id.setter
    def destination_resource_id(self, destination_resource_id):
        """
        Sets the destination_resource_id of this SearchMonitoredResourceMembersDetails.
        Destination Monitored Resource Identifier `OCID`__

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param destination_resource_id: The destination_resource_id of this SearchMonitoredResourceMembersDetails.
        :type: str
        """
        self._destination_resource_id = destination_resource_id

    @property
    def limit_level(self):
        """
        Gets the limit_level of this SearchMonitoredResourceMembersDetails.
        The field which determines the depth of hierarchy while searching for members


        :return: The limit_level of this SearchMonitoredResourceMembersDetails.
        :rtype: int
        """
        return self._limit_level

    @limit_level.setter
    def limit_level(self, limit_level):
        """
        Sets the limit_level of this SearchMonitoredResourceMembersDetails.
        The field which determines the depth of hierarchy while searching for members


        :param limit_level: The limit_level of this SearchMonitoredResourceMembersDetails.
        :type: int
        """
        self._limit_level = limit_level

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class StartAuditTrailDetails(object):
    """
    The details used to  start an audit trail.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new StartAuditTrailDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param audit_collection_start_time:
            The value to assign to the audit_collection_start_time property of this StartAuditTrailDetails.
        :type audit_collection_start_time: datetime

        :param is_auto_purge_enabled:
            The value to assign to the is_auto_purge_enabled property of this StartAuditTrailDetails.
        :type is_auto_purge_enabled: bool

        """
        self.swagger_types = {
            'audit_collection_start_time': 'datetime',
            'is_auto_purge_enabled': 'bool'
        }

        self.attribute_map = {
            'audit_collection_start_time': 'auditCollectionStartTime',
            'is_auto_purge_enabled': 'isAutoPurgeEnabled'
        }

        self._audit_collection_start_time = None
        self._is_auto_purge_enabled = None

    @property
    def audit_collection_start_time(self):
        """
        **[Required]** Gets the audit_collection_start_time of this StartAuditTrailDetails.
        The date from which the audit trail must start collecting data, in the format defined by RFC3339.


        :return: The audit_collection_start_time of this StartAuditTrailDetails.
        :rtype: datetime
        """
        return self._audit_collection_start_time

    @audit_collection_start_time.setter
    def audit_collection_start_time(self, audit_collection_start_time):
        """
        Sets the audit_collection_start_time of this StartAuditTrailDetails.
        The date from which the audit trail must start collecting data, in the format defined by RFC3339.


        :param audit_collection_start_time: The audit_collection_start_time of this StartAuditTrailDetails.
        :type: datetime
        """
        self._audit_collection_start_time = audit_collection_start_time

    @property
    def is_auto_purge_enabled(self):
        """
        Gets the is_auto_purge_enabled of this StartAuditTrailDetails.
        Indicates if auto purge is enabled on the target database, which helps delete audit data in the
        target database every seven days so that the database's audit trail does not become too large.


        :return: The is_auto_purge_enabled of this StartAuditTrailDetails.
        :rtype: bool
        """
        return self._is_auto_purge_enabled

    @is_auto_purge_enabled.setter
    def is_auto_purge_enabled(self, is_auto_purge_enabled):
        """
        Sets the is_auto_purge_enabled of this StartAuditTrailDetails.
        Indicates if auto purge is enabled on the target database, which helps delete audit data in the
        target database every seven days so that the database's audit trail does not become too large.


        :param is_auto_purge_enabled: The is_auto_purge_enabled of this StartAuditTrailDetails.
        :type: bool
        """
        self._is_auto_purge_enabled = is_auto_purge_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .patch_instruction import PatchInstruction
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchRemoveInstruction(PatchInstruction):
    """
    An operation that deletes items, ignoring NOT_FOUND exceptions. To avoid referential errors if an item's descendant is also in the selection, items of the selection are processed in order of decreasing depth.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PatchRemoveInstruction object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.PatchRemoveInstruction.operation` attribute
        of this class is ``REMOVE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation:
            The value to assign to the operation property of this PatchRemoveInstruction.
            Allowed values for this property are: "INSERT", "REMOVE", "MERGE"
        :type operation: str

        :param selection:
            The value to assign to the selection property of this PatchRemoveInstruction.
        :type selection: str

        """
        self.swagger_types = {
            'operation': 'str',
            'selection': 'str'
        }

        self.attribute_map = {
            'operation': 'operation',
            'selection': 'selection'
        }

        self._operation = None
        self._selection = None
        self._operation = 'REMOVE'

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModelDeploymentSummary(object):
    """
    Summary information for a model deployment.
    """

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a ModelDeploymentSummary.
    #: This constant has a value of "NEEDS_ATTENTION"
    LIFECYCLE_STATE_NEEDS_ATTENTION = "NEEDS_ATTENTION"

    def __init__(self, **kwargs):
        """
        Initializes a new ModelDeploymentSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ModelDeploymentSummary.
        :type id: str

        :param time_created:
            The value to assign to the time_created property of this ModelDeploymentSummary.
        :type time_created: datetime

        :param display_name:
            The value to assign to the display_name property of this ModelDeploymentSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this ModelDeploymentSummary.
        :type description: str

        :param project_id:
            The value to assign to the project_id property of this ModelDeploymentSummary.
        :type project_id: str

        :param created_by:
            The value to assign to the created_by property of this ModelDeploymentSummary.
        :type created_by: str

        :param compartment_id:
            The value to assign to the compartment_id property of this ModelDeploymentSummary.
        :type compartment_id: str

        :param model_deployment_configuration_details:
            The value to assign to the model_deployment_configuration_details property of this ModelDeploymentSummary.
        :type model_deployment_configuration_details: oci.data_science.models.ModelDeploymentConfigurationDetails

        :param category_log_details:
            The value to assign to the category_log_details property of this ModelDeploymentSummary.
        :type category_log_details: oci.data_science.models.CategoryLogDetails

        :param model_deployment_url:
            The value to assign to the model_deployment_url property of this ModelDeploymentSummary.
        :type model_deployment_url: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this ModelDeploymentSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "FAILED", "INACTIVE", "UPDATING", "DELETED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ModelDeploymentSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ModelDeploymentSummary.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'time_created': 'datetime',
            'display_name': 'str',
            'description': 'str',
            'project_id': 'str',
            'created_by': 'str',
            'compartment_id': 'str',
            'model_deployment_configuration_details': 'ModelDeploymentConfigurationDetails',
            'category_log_details': 'CategoryLogDetails',
            'model_deployment_url': 'str',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'time_created': 'timeCreated',
            'display_name': 'displayName',
            'description': 'description',
            'project_id': 'projectId',
            'created_by': 'createdBy',
            'compartment_id': 'compartmentId',
            'model_deployment_configuration_details': 'modelDeploymentConfigurationDetails',
            'category_log_details': 'categoryLogDetails',
            'model_deployment_url': 'modelDeploymentUrl',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._id = None
        self._time_created = None
        self._display_name = None
        self._description = None
        self._project_id = None
        self._created_by = None
        self._compartment_id = None
        self._model_deployment_configuration_details = None
        self._category_log_details = None
        self._model_deployment_url = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this ModelDeploymentSummary.
        The `OCID`__ of the model deployment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ModelDeploymentSummary.
        The `OCID`__ of the model deployment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this ModelDeploymentSummary.
        :type: str
        """
        self._id = id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ModelDeploymentSummary.
        The date and time the resource was created, in the timestamp format defined by `RFC3339`__.
        Example: 2019-08-25T21:10:29.41Z

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ModelDeploymentSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ModelDeploymentSummary.
        The date and time the resource was created, in the timestamp format defined by `RFC3339`__.
        Example: 2019-08-25T21:10:29.41Z

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ModelDeploymentSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ModelDeploymentSummary.
        A user-friendly display name for the resource. Does not have to be unique, and can be modified. Avoid entering confidential information.
        Example: `My ModelDeployment`


        :return: The display_name of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ModelDeploymentSummary.
        A user-friendly display name for the resource. Does not have to be unique, and can be modified. Avoid entering confidential information.
        Example: `My ModelDeployment`


        :param display_name: The display_name of this ModelDeploymentSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this ModelDeploymentSummary.
        A short description of the model deployment.


        :return: The description of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ModelDeploymentSummary.
        A short description of the model deployment.


        :param description: The description of this ModelDeploymentSummary.
        :type: str
        """
        self._description = description

    @property
    def project_id(self):
        """
        **[Required]** Gets the project_id of this ModelDeploymentSummary.
        The `OCID`__ of the project associated with the model deployment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The project_id of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """
        Sets the project_id of this ModelDeploymentSummary.
        The `OCID`__ of the project associated with the model deployment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param project_id: The project_id of this ModelDeploymentSummary.
        :type: str
        """
        self._project_id = project_id

    @property
    def created_by(self):
        """
        **[Required]** Gets the created_by of this ModelDeploymentSummary.
        The `OCID`__ of the user who created the model deployment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The created_by of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ModelDeploymentSummary.
        The `OCID`__ of the user who created the model deployment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param created_by: The created_by of this ModelDeploymentSummary.
        :type: str
        """
        self._created_by = created_by

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this ModelDeploymentSummary.
        The `OCID`__ of the model deployment's compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this ModelDeploymentSummary.
        The `OCID`__ of the model deployment's compartment.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this ModelDeploymentSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def model_deployment_configuration_details(self):
        """
        Gets the model_deployment_configuration_details of this ModelDeploymentSummary.

        :return: The model_deployment_configuration_details of this ModelDeploymentSummary.
        :rtype: oci.data_science.models.ModelDeploymentConfigurationDetails
        """
        return self._model_deployment_configuration_details

    @model_deployment_configuration_details.setter
    def model_deployment_configuration_details(self, model_deployment_configuration_details):
        """
        Sets the model_deployment_configuration_details of this ModelDeploymentSummary.

        :param model_deployment_configuration_details: The model_deployment_configuration_details of this ModelDeploymentSummary.
        :type: oci.data_science.models.ModelDeploymentConfigurationDetails
        """
        self._model_deployment_configuration_details = model_deployment_configuration_details

    @property
    def category_log_details(self):
        """
        Gets the category_log_details of this ModelDeploymentSummary.

        :return: The category_log_details of this ModelDeploymentSummary.
        :rtype: oci.data_science.models.CategoryLogDetails
        """
        return self._category_log_details

    @category_log_details.setter
    def category_log_details(self, category_log_details):
        """
        Sets the category_log_details of this ModelDeploymentSummary.

        :param category_log_details: The category_log_details of this ModelDeploymentSummary.
        :type: oci.data_science.models.CategoryLogDetails
        """
        self._category_log_details = category_log_details

    @property
    def model_deployment_url(self):
        """
        **[Required]** Gets the model_deployment_url of this ModelDeploymentSummary.
        The URL to interact with the model deployment.


        :return: The model_deployment_url of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._model_deployment_url

    @model_deployment_url.setter
    def model_deployment_url(self, model_deployment_url):
        """
        Sets the model_deployment_url of this ModelDeploymentSummary.
        The URL to interact with the model deployment.


        :param model_deployment_url: The model_deployment_url of this ModelDeploymentSummary.
        :type: str
        """
        self._model_deployment_url = model_deployment_url

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this ModelDeploymentSummary.
        The state of the model deployment.

        Allowed values for this property are: "CREATING", "ACTIVE", "DELETING", "FAILED", "INACTIVE", "UPDATING", "DELETED", "NEEDS_ATTENTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this ModelDeploymentSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this ModelDeploymentSummary.
        The state of the model deployment.


        :param lifecycle_state: The lifecycle_state of this ModelDeploymentSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "DELETING", "FAILED", "INACTIVE", "UPDATING", "DELETED", "NEEDS_ATTENTION"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this ModelDeploymentSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this ModelDeploymentSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this ModelDeploymentSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. See `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this ModelDeploymentSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this ModelDeploymentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this ModelDeploymentSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this ModelDeploymentSummary.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. See `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this ModelDeploymentSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JavaRuntimeId(object):
    """
    The essential properties to identify a Java Runtime.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JavaRuntimeId object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param version:
            The value to assign to the version property of this JavaRuntimeId.
        :type version: str

        :param vendor:
            The value to assign to the vendor property of this JavaRuntimeId.
        :type vendor: str

        :param distribution:
            The value to assign to the distribution property of this JavaRuntimeId.
        :type distribution: str

        :param jre_key:
            The value to assign to the jre_key property of this JavaRuntimeId.
        :type jre_key: str

        """
        self.swagger_types = {
            'version': 'str',
            'vendor': 'str',
            'distribution': 'str',
            'jre_key': 'str'
        }

        self.attribute_map = {
            'version': 'version',
            'vendor': 'vendor',
            'distribution': 'distribution',
            'jre_key': 'jreKey'
        }

        self._version = None
        self._vendor = None
        self._distribution = None
        self._jre_key = None

    @property
    def version(self):
        """
        **[Required]** Gets the version of this JavaRuntimeId.
        The version of the Java Runtime.


        :return: The version of this JavaRuntimeId.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this JavaRuntimeId.
        The version of the Java Runtime.


        :param version: The version of this JavaRuntimeId.
        :type: str
        """
        self._version = version

    @property
    def vendor(self):
        """
        **[Required]** Gets the vendor of this JavaRuntimeId.
        The vendor of the Java Runtime.


        :return: The vendor of this JavaRuntimeId.
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """
        Sets the vendor of this JavaRuntimeId.
        The vendor of the Java Runtime.


        :param vendor: The vendor of this JavaRuntimeId.
        :type: str
        """
        self._vendor = vendor

    @property
    def distribution(self):
        """
        **[Required]** Gets the distribution of this JavaRuntimeId.
        The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.


        :return: The distribution of this JavaRuntimeId.
        :rtype: str
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """
        Sets the distribution of this JavaRuntimeId.
        The distribution of a Java Runtime is the name of the lineage of product to which it belongs, for example _Java(TM) SE Runtime Environment_.


        :param distribution: The distribution of this JavaRuntimeId.
        :type: str
        """
        self._distribution = distribution

    @property
    def jre_key(self):
        """
        Gets the jre_key of this JavaRuntimeId.
        The unique identifier for a Java Runtime.


        :return: The jre_key of this JavaRuntimeId.
        :rtype: str
        """
        return self._jre_key

    @jre_key.setter
    def jre_key(self, jre_key):
        """
        Sets the jre_key of this JavaRuntimeId.
        The unique identifier for a Java Runtime.


        :param jre_key: The jre_key of this JavaRuntimeId.
        :type: str
        """
        self._jre_key = jre_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
